 /***********************************************************************
 *                                                                      *
 * port.c                                                               *
 * This is port driver program file for SVT17702.                       *
 * History :  2008/03/26  Start.                                        *
 *                                                                      *
 ************************************************************************/

 /* #include */
 #include "s1c17702.h"
 #include "port.h"

 /************************************************************************
 * 	 setPortInput function.
 *   Port is set up in the input mode.
 *   param    :     unsigned char inputBitP0 D0:P00 D1:P01 D2:P02 D3:P03 D4:P04 D5:P05 D6:P06 D7:P07
 *                  unsigned char inputBitP1 D0:P10 D1:P11 D2:P12 D3:P13 D4:P14 D5:P15 D6:P16 D7:P17
 *                  unsigned char inputBitP2 D0:P20 D1:P21 D2:P22 D3:P23 D4:P24 D5:P25 D6:P26 D7:P27
 *                  unsigned char inputBitP3 D0:P30 D1:P31 D2:P32 D3:P33 
 *   return   :     none
 *   history  :     2008/03/26	start
 ***********************************************************************/
  void setPortInput(unsigned char inputBitP0, unsigned char inputBitP1, unsigned char inputBitP2, unsigned char inputBitP3) {
	// P0X Direction control (D[0:7]/0x5202)
	P0_IO &= (~inputBitP0);
	// P1X Direction control (D[0:7]/0x5212)
	P1_IO &= (~inputBitP1);
	// P2X Direction control (D[0:7]/0x5222)
	P2_IO &= (~inputBitP2);
	// P3X Direction control (D[0:3]/0x5232)
	inputBitP3 &= 0x0f;
	P3_IO &= (~inputBitP3);
  }

 /************************************************************************
 * 	 setPortOutput function.
 *   Port is set up in the output mode.
 *   param    :     unsigned char outputBitP0 D0:P00 D1:P01 D2:P02 D3:P03 D4:P04 D5:P05 D6:P06 D7:P07
 *                  unsigned char outputBitP1 D0:P10 D1:P11 D2:P12 D3:P13 D4:P14 D5:P15 D6:P16 D7:P17
 *                  unsigned char outputBitP2 D0:P20 D1:P21 D2:P22 D3:P23 D4:P24 D5:P25 D6:P26 D7:P27
 *                  unsigned char outputBitP3 D0:P30 D1:P31 D2:P32 D3:P33 
 *   return   :     none
 *   history  :     2008/03/26	start
 ***********************************************************************/
 void setPortOutput(unsigned char outputBitP0, unsigned char outputBitP1, unsigned char outputBitP2, unsigned char outputBitP3) {
	// P0X Direction control (D[0:7]/0x5202)
	P0_IO |= outputBitP0;
	// P1X Direction control (D[0:7]/0x5212)
	P1_IO |= outputBitP1;
	// P2X Direction control (D[0:7]/0x5222)
	P2_IO |= outputBitP2;
	// P3X Direction control (D[0:3]/0x5232)
	outputBitP3 &= 0x0f;
	P3_IO |= outputBitP3;
 }

 /************************************************************************
 * 	 setPortPullupOn function.
 *   Port is set up in the pullup on.
 *   param    :     unsigned char onBitP0 D0:P00 D1:P01 D2:P02 D3:P03 D4:P04 D5:P05 D6:P06 D7:P07
 *                  unsigned char onBitP1 D0:P10 D1:P11 D2:P12 D3:P13 D4:P14 D5:P15 D6:P16 D7:P17
 *                  unsigned char onBitP2 D0:P20 D1:P21 D2:P22 D3:P23 D4:P24 D5:P25 D6:P26 D7:P27
 *                  unsigned char onBitP3 D0:P30 D1:P31 D2:P32 D3:P33 
 *   return   :     none
 *   history  :     2008/03/26	start
 ***********************************************************************/
 void setPortPullupOn(unsigned char onBitP0, unsigned char onBitP1, unsigned char onBitP2, unsigned char onBitP3) {
	// P0X pullup control (D[0:7]/0x5203)
	P0_PU |= onBitP0;
	
	// P1X pullup control (D[0:7]/0x5213)
	P1_PU |= onBitP1;

	// P2X pullup control (D[0:7]/0x5223)
	P2_PU |= onBitP2;

	// P3X pullup control (D[0:3]/0x5233)
	onBitP3 &= 0x0f;
	P3_PU |= onBitP3;
 }

 /************************************************************************
 * 	 setPortPullupOff function.
 *   Port is set up in the pullup off.
 *   param    :     unsigned char offBitP0 D0:P00 D1:P01 D2:P02 D3:P03 D4:P04 D5:P05 D6:P06 D7:P07
 *                  unsigned char offBitP1 D0:P10 D1:P11 D2:P12 D3:P13 D4:P14 D5:P15 D6:P16 D7:P17
 *                  unsigned char offBitP2 D0:P20 D1:P21 D2:P22 D3:P23 D4:P24 D5:P25 D6:P26 D7:P27
 *                  unsigned char offBitP3 D0:P30 D1:P31 D2:P32 D3:P33 
 *   return   :     none
 *   history  :     2008/03/26	start
 ***********************************************************************/
 void setPortPullupOff(unsigned char offBitP0, unsigned char offBitP1, unsigned char offBitP2, unsigned char offBitP3) {
	// P0X pullup control (D[0:7]/0x5203)
	P0_PU &= (~offBitP0);
	
	// P1X pullup control (D[0:7]/0x5213)
	P1_PU &= (~offBitP1);

	// P2X pullup control (D[0:7]/0x5223)
	P2_PU &= (~offBitP2);

	// P3X pullup control (D[0:3]/0x5233)
	offBitP3 &= 0x0f;
	P3_PU &= (~offBitP3);
 }

 /************************************************************************
 * 	 setPortCmosSchimitt function.
 *   Port is set up in the schimitt.
 *   param    :     unsigned char schimittBitP0 D0:P00 D1:P01 D2:P02 D3:P03 D4:P04 D5:P05 D6:P06 D7:P07
 *                  unsigned char schimittBitP1 D0:P10 D1:P11 D2:P12 D3:P13 D4:P14 D5:P15 D6:P16 D7:P17
 *                  unsigned char schimittBitP2 D0:P20 D1:P21 D2:P22 D3:P23 D4:P24 D5:P25 D6:P26 D7:P27
 *                  unsigned char schimittBitP3 D0:P30 D1:P31 D2:P32 D3:P33 
 *   return   :     none
 *   history  :     2008/03/26	start
 ***********************************************************************/
 void setPortCmosSchimitt(unsigned char schimittBitP0, unsigned char schimittBitP1, unsigned char schimittBitP2, unsigned char schimittBitP3) {
	// P0X Schimitt control (D[0:7]/0x5204)
	P0_SM |= schimittBitP0;
	
	// P0X Schimitt control (D[0:7]/0x5214)
	P1_SM |= schimittBitP1;
	
	// P0X Schimitt control (D[0:7]/0x5224)
	P2_SM |= schimittBitP2;	
	
	// P0X Schimitt control (D[0:3]/0x5234)
	schimittBitP3 &= 0x0f;
	P3_SM |= schimittBitP3;

 }

 /************************************************************************
 * 	 setPortCmos function.
 *   Port is set up in the cmos.
 *   param    :     unsigned char cmosBitP0 D0:P00 D1:P01 D2:P02 D3:P03 D4:P04 D5:P05 D6:P06 D7:P07
 *                  unsigned char cmosBitP1 D0:P10 D1:P11 D2:P12 D3:P13 D4:P14 D5:P15 D6:P16 D7:P17
 *                  unsigned char cmosBitP2 D0:P20 D1:P21 D2:P22 D3:P23 D4:P24 D5:P25 D6:P26 D7:P27
 *                  unsigned char cmosBitP3 D0:P30 D1:P31 D2:P32 D3:P33 
 *   return   :     none
 *   history  :     2008/03/26	start
 ***********************************************************************/
 void setPortCmos(unsigned char cmosBitP0, unsigned char cmosBitP1, unsigned char cmosBitP2, unsigned char cmosBitP3) {
	// P0X Schimitt control (D[0:7]/0x5204)
	P0_SM &= (~cmosBitP0);
	
	// P0X Schimitt control (D[0:7]/0x5214)
	P1_SM &= (~cmosBitP1);
	
	// P0X Schimitt control (D[0:7]/0x5224)
	P2_SM &= (~cmosBitP2);
	
	// P0X Schimitt control (D[0:3]/0x5234)
	cmosBitP3 &= 0x0f;
	P3_SM &= (~cmosBitP3);
 }
 

 /************************************************************************
 * 	 setP0Chat0to3 function.
 *   Port0 is set up in the chattaring time.
 *   param    :     unsigned char time 0x0:off
 *                            		   0x1:256/PCLK(128us)
 *                            		   0x2:512/PCLK(256us)
 *                            		   0x3:1024/PCLK(512us)
 *                            		   0x4:2048/PCLK(1ms)
 *                            		   0x5:4096/PCLK(2ms)
 *                            		   0x6:8192/PCLK(4ms)
 *                            		   0x7:16384/PCLK(8ms)
 *   return   :     none
 *   history  :     2008/03/26	start
 ***********************************************************************/
 void setP0Chat0to3(unsigned char time) {
	//interrupt disable (D[0:7] /0x5205)
	P0_IMSK = 0x00;
	//chattering filter time P0 (D[2:0] /0x5208)
	P0_CHAT_P0CF1 = time;
 }

 /************************************************************************
 * 	 setP0Chat4to7 function.
 *   Port0 is set up in the chattaring time.
 *   param    :     unsigned char time 0x0:off
 *                             		   0x1:256/PCLK(128us)
 *                             		   0x2:512/PCLK(256us)
 *                             		   0x3:1024/PCLK(512us)
 *                             		   0x4:2048/PCLK(1ms)
 *                             		   0x5:4096/PCLK(2ms)
 *                             		   0x6:8192/PCLK(4ms)
 *                             		   0x7:16384/PCLK(8ms)
 *   return   :     none
 *   history  :     2008/03/26	start
 ***********************************************************************/
 void setP0Chat4to7(unsigned char time) {
	//interrupt disable (D[0:7] /0x5205)
	P0_IMSK = 0x00;
	//chattering filter time P0 (D[4:6] /0x5208)
	P0_CHAT_P0CF2 = time;
 }
 
 /************************************************************************
 * 	 setP1Chat0to3 function.
 *   Port1 is set up in the chattaring time.
 *   param    :     unsigned char time 0x0:off
 *                            		   0x1:256/PCLK(128us)
 *                            		   0x2:512/PCLK(256us)
 *                            		   0x3:1024/PCLK(512us)
 *                            		   0x4:2048/PCLK(1ms)
 *                            		   0x5:4096/PCLK(2ms)
 *                            		   0x6:8192/PCLK(4ms)
 *                            		   0x7:16384/PCLK(8ms)
 *   return   :     none
 *   history  :     2008/08/08	start
 ***********************************************************************/
 void setP1Chat0to3(unsigned char time) {
	//interrupt disable (D[0:7] /0x5215)
	P1_IMSK = 0x00;
	//chattering filter time P0 (D[2:0] /0x5218)
	P1_CHAT_P1CF1 = time;
 }

 /************************************************************************
 * 	 setP1Chat4to7 function.
 *   Port1 is set up in the chattaring time.
 *   param    :     unsigned char time 0x0:off
 *                             		   0x1:256/PCLK(128us)
 *                             		   0x2:512/PCLK(256us)
 *                             		   0x3:1024/PCLK(512us)
 *                             		   0x4:2048/PCLK(1ms)
 *                             		   0x5:4096/PCLK(2ms)
 *                             		   0x6:8192/PCLK(4ms)
 *                             		   0x7:16384/PCLK(8ms)
 *   return   :     none
 *   history  :     2008/08/08	start
 ***********************************************************************/
 void setP1Chat4to7(unsigned char time) {
	//interrupt disable (D[0:7] /0x5215)
	P1_IMSK = 0x00;
	//chattering filter time P0 (D[4:6] /0x5218)
	P1_CHAT_P1CF2 = time;
 } 

 /************************************************************************
 * 	 getPInput function.
 *   Get port data.
 *   param    :     unsigned char portNo 0:P0 Port
 *                              		 1:P1 Port
 *                           			 2:P2 Port
 *                               		 3:P3 Port
 *   return   :     unsigned char port data
 *   history  :     2008/03/26	start
 ***********************************************************************/
 unsigned char getPInput(unsigned char portNo) {
	/* port data*/
	unsigned char portData;
	
	switch(portNo) {
		case P_PORTNO_P0:
			//Port Data (D[0:7] /0x5200)
			portData = P0_IN;
			break;
		case P_PORTNO_P1:
			//Port Data (D[0:7] /0x5210)
			portData = P1_IN;
			break;
		case P_PORTNO_P2:
			//Port Data (D[0:7] /0x5220)
			portData = P2_IN;
			break;
		case P_PORTNO_P3:
			//Port Data (D[0:3] /0x5230)
			portData = P3_IN;
			break;
		default:
			portData = 0;
			break;
	}

	return portData;
 }
 
 /************************************************************************
 * 	 setPoutput function.
 *   Set port data.
 *   param    :     unsigned char portNo 0:P0 Port
 *                               		 1:P1 Port
 *                              		 2:P2 Port
 *                              		 3:P3 Port
 *                  unsigned char data OUTPUT Data
 *   return   :     none
 *   history  :     2008/03/26	start
 ***********************************************************************/
 void setPoutput(unsigned char portNo, unsigned char data) {
	switch(portNo) {
		case P_PORTNO_P0:
			//Port output Data (D[0:7] /0x5201)
			P0_OUT = data;
			break;
		case P_PORTNO_P1:
			//Port output Data (D[0:7] /0x5211)
			P1_OUT = data;
			break;
		case P_PORTNO_P2:
			//Port output Data (D[0:7] /0x5221)
			P2_OUT = data;
			break;
		case P_PORTNO_P3:
			//Port output Data (D[0:3] /0x5231)
			P3_OUT = data;
			break;
	}

 }

 /************************************************************************
 * 	 setPortOutDataH function.
 *   Set port HIGH data.
 *   param    :     unsigned char putBitP0 D0:P00 D1:P01 D2:P02 D3:P03 D4:P04 D5:P05 D6:P06 D7:P07
 *                  unsigned char putBitP1 D0:P00 D1:P01 D2:P02 D3:P03 D4:P04 D5:P05 D6:P06 D7:P07
 *                  unsigned char putBitP2 D0:P00 D1:P01 D2:P02 D3:P03 D4:P04 D5:P05 D6:P06 D7:P07
 *                  unsigned char putBitP3 D0:P00 D1:P01 D2:P02 D3:P03 D4:P04 D5:P05 D6:P06 D7:P07
 *   return   :     none
 *   history  :     2008/03/26	start
 ***********************************************************************/
 void setPortOutDataH(unsigned char putBitP0, unsigned char putBitP1, unsigned char putBitP2, unsigned char putBitP3) {
	//Port output Data (D[0:7] /0x5201)
	P0_OUT |= putBitP0;
	
	//Port output Data (D[0:7] /0x5211)
	P1_OUT |= putBitP1;
	
	//Port output Data (D[0:7] /0x5221)
	P2_OUT |= putBitP2;
	
	//Port output Data (D[0:3] /0x5231)
	putBitP3 &= 0x0f;
	P3_OUT |= putBitP3;
 }

 /************************************************************************
 * 	 setPortOutDataL function.
 *   Set port LOW data.
 *   param    :     unsigned char putBitP0 D0:P00 D1:P01 D2:P02 D3:P03 D4:P04 D5:P05 D6:P06 D7:P07
 *                  unsigned char putBitP1 D0:P00 D1:P01 D2:P02 D3:P03 D4:P04 D5:P05 D6:P06 D7:P07
 *                  unsigned char putBitP2 D0:P00 D1:P01 D2:P02 D3:P03 D4:P04 D5:P05 D6:P06 D7:P07
 *                  unsigned char putBitP3 D0:P00 D1:P01 D2:P02 D3:P03 D4:P04 D5:P05 D6:P06 D7:P07
 *   return   :     none
 *   history  :     2008/03/26	start
 ***********************************************************************/
 void setPortOutDataL(unsigned char putBitP0, unsigned char putBitP1, unsigned char putBitP2, unsigned char putBitP3) {
	//Port output Data (D[0:7] /0x5201)
	P0_OUT &= (~putBitP0);
	
	//Port output Data (D[0:7] /0x5211)
	P1_OUT &= (~putBitP1);
	
	//Port output Data (D[0:7] /0x5221)
	P2_OUT &= (~putBitP2);
	
	//Port output Data (D[0:3] /0x5231)
	putBitP3 &= 0x0f;
	P3_OUT &= (~putBitP3);
 }

 /************************************************************************
 * 	 initP0Int function.
 *   initialize port0 interrupt.
 *   param    :     unsigned char intLevel:interrput level
 * 					unsigned char edgeBit: interrupt edge
 *   return   :     none
 *   history  :     2008/03/26	start
 ***********************************************************************/
 void initP0Int(unsigned char intLevel) {
	// P0 port interrupt disable (D[0:7] /0x5205)
	stopP0Int(0xff);
	
	// P0 port interrupt level (D[0:2] /0x4306)
	ITC_LV0_ILV0 = intLevel;

 }

 /************************************************************************
 * 	 initP1Int function.
 *   initialize port1 interrupt.
 *   param    :     unsigned char intLevel:interrput level
 * 					unsigned char edgeBit: interrupt edge
 *   return   :     none
 *   history  :     2008/03/26	start
 ***********************************************************************/
 void initP1Int(unsigned char intLevel) {
	// P1 port interrupt disable (D[0:7] /0x5215)
	stopP1Int(0xff);	
	
	// P1 port interrupt level (D[8:10] /0x4306)
	ITC_LV0_ILV1 = intLevel;

 }
 
 /************************************************************************
 * 	 startP0Int function.
 *   Start port0 interrupt.
 *   param    :     unsigned char startBit D0:P00 D1:P01 D2:P02 D3:P03 
 * 										   D4:P04 D5:P05 D6:P06 D7:P07
 *   return   :     none
 *   history  :     2007/03/26	start
 ***********************************************************************/
 void startP0Int(unsigned char startBit) {
	resetP0IF(0xff);

	// P0 Port Interrupt Mask Register (D[0:7] /0x5205)
	P0_IMSK |= startBit;
 }
 
 /************************************************************************
 * 	 startP1Int function.
 *   Start por1t interrupt.
 *   param    :     unsigned char startBit D0:P00 D1:P01 D2:P02 D3:P03
 * 										   D4:P04 D5:P05 D6:P06 D7:P07
 *   return   :     none
 *   history  :     2007/03/26	start
 ***********************************************************************/
 void startP1Int(unsigned char startBit) {
	resetP1IF(0xff);
	
	// P1 Port Interrupt Mask Register (D[0:7] /0x5215)
	P1_IMSK |= startBit;
 }

 /************************************************************************
 * 	 stopP0Int function.
 *   Stop port0 interrupt.
 *   param    :     unsigned char stopBit D0:P00 D1:P01 D2:P02 D3:P03 
 * 										  D4:P04 D5:P05 D6:P06 D7:P07
 *   return   :     none
 *   history  :     2008/03/26	start
 ***********************************************************************/
 void stopP0Int(unsigned char stopBit) {
	// P0 Port Interrupt Mask Register (D[0:7] /0x5205)
	P0_IMSK &= (~stopBit);

 }

 /************************************************************************
 * 	 stopP1Int function.
 *   Stop port1 interrupt.
 *   param    :     unsigned char stopBit D0:P00 D1:P01 D2:P02 D3:P03 
 * 										  D4:P04 D5:P05 D6:P06 D7:P07
 *   return   :     none
 *   history  :     2008/03/26	start
 ***********************************************************************/
 void stopP1Int(unsigned char stopBit) {
	// P0 Port Interrupt Mask Register (D[0:7] /0x5215)
	P1_IMSK &= (~stopBit);
 }
 

 /************************************************************************
 * 	 resetP0IF function.
 *   Reset port0 interrupt flag.
 *   param    :     unsigned char resetBit D0:P00 D1:P01 D2:P02 D3:P03 
 * 										   D4:P04 D5:P05 D6:P06 D7:P07
 *   return   :     none
 *   history  :     2008/03/26	start
 ***********************************************************************/
 void resetP0IF(unsigned char resetBit) {
	//port interrupt flag (D[0:7] /0x5207
	P0_IFLG = resetBit;
 }
 

 /************************************************************************
 * 	 resetP1IF function.
 *   Reset port1 interrupt flag.
 *   param    :     unsigned char resetBit D0:P00 D1:P01 D2:P02 D3:P03 
 * 										   D4:P04 D5:P05 D6:P06 D7:P07
 *   return   :     none
 *   history  :     2008/03/26	start
 ***********************************************************************/
 void resetP1IF(unsigned char resetBit) {
	//port interrupt flag (D[0:7] /0x5217
	P1_IFLG = resetBit;
 }

 /************************************************************************
 * 	 contorlP0IputOn function.
 *   P0 port input enable setting.
 *   param    :     unsigned char setBit   D0:P00 D1:P01 D2:P02 D3:P03 
 * 										   D4:P04 D5:P05 D6:P06 D7:P07
 *   return   :     none
 *   history  :     2007/03/26	start
 ***********************************************************************/
 void contorlP0IputOn(unsigned char setBit) {
 	// P0 Port Input Enable (D[0:7] /0x520a)
 	P0_IEN_P0IEN |= setBit;

 }
 
 /************************************************************************
 * 	 contorlP1IputOn function.
 *   P1 port input enable setting.
 *   param    :     unsigned char setBit   D0:P00 D1:P01 D2:P02 D3:P03 
 * 										   D4:P04 D5:P05 D6:P06 D7:P07
 *   return   :     none
 *   history  :     2007/03/26	start
 ***********************************************************************/
 void contorlP1IputOn(unsigned char setBit) {
 	// P1 Port Input Enable (D[0:7] /0x521a)
 	P1_IEN_P1IEN |= setBit;

 }
 
 /************************************************************************
 * 	 contorlP2IputOn function. 
 *   P2 port input enable setting.
 *   param    :     unsigned char setBit   D0:P00 D1:P01 D2:P02 D3:P03 
 * 										   D4:P04 D5:P05 D6:P06 D7:P07
 *   return   :     none
 *   history  :     2007/03/26	start
 ***********************************************************************/
 void contorlP2IputOn(unsigned char setBit) {
 	// P2 Port Input Enable (D[0:7] /0x522a)
 	P2_IEN_P2IEN |= setBit;

 }
 
 /************************************************************************
 * 	 contorlP3IputOn function. 
 *   P2 port input enable setting.
 *   param    :     unsigned char setBit   D0:P00 D1:P01 D2:P02 D3:P03 
 * 										   D4:P04 D5:P05 D6:P06 D7:P07
 *   return   :     none
 *   history  :     2007/03/26	start
 ***********************************************************************/
 void contorlP3IputOn(unsigned char setBit) {
 	// P3 Port Input Enable (D[0:7] /0x523a)
 	P3_IEN_P3IEN |= setBit;

 }
 
 /************************************************************************
 *   contorlP0IputOff function.
 *   P0 port input disable setting.
 *   param    :     unsigned char setBit   D0:P00 D1:P01 D2:P02 D3:P03 
 * 										   D4:P04 D5:P05 D6:P06 D7:P07
 *   return   :     none
 *   history  :     2007/03/26	start
 ***********************************************************************/
 void contorlP0IputOff(unsigned char setBit) {
 	// P0 Port Input Disable (D[0:7] /0x520a)
    P0_IEN_P0IEN &= (~setBit);

 }
 
 /************************************************************************
 * 	 contorlP1IputOff function. 
 *   P1 port input disable setting.
 *   param    :     unsigned char setBit   D0:P00 D1:P01 D2:P02 D3:P03 
 * 										   D4:P04 D5:P05 D6:P06 D7:P07
 *   return   :     none
 *   history  :     2007/03/26	start
 ***********************************************************************/
 void contorlP1IputOff(unsigned char setBit) {
 	// P1 Port Input Disable (D[0:7] /0x521a)
    P1_IEN_P1IEN &= (~setBit);

 }
 
 /************************************************************************
 * 	 contorlP2IputOff function. 
 *   P2 port input disable setting.
 *   param    :     unsigned char setBit   D0:P00 D1:P01 D2:P02 D3:P03 
 * 										   D4:P04 D5:P05 D6:P06 D7:P07
 *   return   :     none
 *   history  :     2007/03/26	start
 ***********************************************************************/
 void contorlP2IputOff(unsigned char setBit) {
 	// P2 Port Input Disable (D[0:7] /0x522a)
    P2_IEN_P2IEN &= (~setBit);

 }

 /************************************************************************
 * 	 contorlP3IputOff function. 
 *   P3 port input disable setting.
 *   param    :     unsigned char setBit   D0:P00 D1:P01 D2:P02 D3:P03 
 * 										   D4:P04 D5:P05 D6:P06 D7:P07
 *   return   :     none
 *   history  :     2007/03/26	start
 ***********************************************************************/
 void contorlP3IputOff(unsigned char setBit) {
 	// P3 Port Input Disable (D[0:7] /0x523a)
    P3_IEN_P3IEN &= (~setBit);

 }

 /************************************************************************
 * 	 setP0IntEdgeUp function.
 *   Setting port0 edge rise mode.
 *   param    :     unsigned char upBit D0:P00 D1:P01 D2:P02 D3:P03 D4:P04 D5:P05 D6:P06 D7:P07
 *   return   :     none
 *   history  :     2008/03/26	start
 ***********************************************************************/
 void setP0IntEdgeUp(unsigned char upBit) {
	//port interrupt edge select D[0:7] /0x5206
	P0_EDGE &= (~upBit);
 }

 /************************************************************************
 * 	 setP1IntEdgeUp function. 
 *   Setting port1 edge rise mode.
 *   param    :     unsigned char upBit D0:P00 D1:P01 D2:P02 D3:P03 D4:P04 D5:P05 D6:P06 D7:P07
 *   return   :     none
 *   history  :     2008/03/26	start
 ***********************************************************************/
 void setP1IntEdgeUp(unsigned char upBit) {
	//port interrupt edge select D[0:7] /0x5216
	P1_EDGE &= (~upBit);

 }

 /************************************************************************
 * 	 setP0IntEdgeDown function.
 *   Setting port0 edge fail mode.
 *   param    :     unsigned char downBit D0:P00 D1:P01 D2:P02 D3:P03 D4:P04 D5:P05 D6:P06 D7:P07
 *   return   :     none
 *   history  :     2008/03/26	start
 ***********************************************************************/
 void setP0IntEdgeDown(unsigned char downBit) {
	//port interrupt edge select D[0:7] /0x5206
	P0_EDGE |= downBit;
 }

 /************************************************************************
 * 	 setP1IntEdgeDown function. 
 *   Setting port1 edge fail mode.
 *   param    :     unsigned char upBit D0:P00 D1:P01 D2:P02 D3:P03 D4:P04 D5:P05 D6:P06 D7:P07
 *   return   :     none
 *   history  :     2008/03/26	start
 ***********************************************************************/
 void setP1IntEdgeDown(unsigned char downBit) {
	//port interrupt edge select D[0:7] /0x5216
	P1_EDGE |= downBit;
 }

 /************************************************************************
 * 	 isP00Int function.
 *   Inquiry is interrupt P00 occured.
 *   param    :     void
 *   return   :     char P_INT_OCCURED       interrupt occured
 *                       P_INT_NOT_OCCURED   interrupt nnot occured
 *   history  :     2008/03/26	start
 ***********************************************************************/
 char isP00Int(void) {
	/* interrupt flag*/
	unsigned char intFlag;
	
	//port interrupt flag (D[0:7] /0x5207
	intFlag = P0_IFLG;

	if((intFlag & P_BIT_X0) == P_BIT_X0) {
		return P_INT_OCCURED;				//interrupt occured
	} else {
		return P_INT_NOT_OCCURED;
	}
 }



 /************************************************************************
 * 	 isP01Int function. 
 *   Inquiry is interrupt P01 occured.
 *   param    :     void
 *   return   :     char P_INT_OCCURED       interrupt occured
 *                       P_INT_NOT_OCCURED   interrupt nnot occured
 *   history  :     2008/03/26	start
 ***********************************************************************/
 char isP01Int(void) {
	/* interrupt flag*/
	unsigned char intFlag;
	
	//port interrupt flag (D[0:7] /0x5207
	intFlag = P0_IFLG;

	if((intFlag & P_BIT_X1) == P_BIT_X1) {
		return P_INT_OCCURED;				//interrupt occured
	} else {
		return P_INT_NOT_OCCURED;
	}
 }

 /************************************************************************
 * 	 isP02Int function. 
 *   Inquiry is interrupt P02 occured.
 *   param    :     void
 *   return   :     char P_INT_OCCURED       interrupt occured
 *                       P_INT_NOT_OCCURED   interrupt nnot occured
 *   history  :     2008/03/26	start
 ***********************************************************************/
 char isP02Int(void) {
	/* interrupt flag*/
	unsigned char intFlag;
	
	//port interrupt flag (D[0:7] /0x5207
	intFlag = P0_IFLG;

	if((intFlag & P_BIT_X2) == P_BIT_X2) {
		return P_INT_OCCURED;				//interrupt occured
	} else {
		return P_INT_NOT_OCCURED;
	}
 }

 /************************************************************************
 * 	 isP03Int function. 
 *   Inquiry is interrupt P03 occured.
 *   param    :     void
 *   return   :     char P_INT_OCCURED       interrupt occured
 *                       P_INT_NOT_OCCURED   interrupt nnot occured
 *   history  :     2008/03/26	start
 ***********************************************************************/
 char isP03Int(void) {
	/* interrupt flag*/
	unsigned char intFlag;
	
	//port interrupt flag (D[0:7] /0x5207
	intFlag = P0_IFLG;

	if((intFlag & P_BIT_X3) == P_BIT_X3) {
		return P_INT_OCCURED;				//interrupt occured
	} else {
		return P_INT_NOT_OCCURED;
	}
 }

 /************************************************************************
 * 	 isP04Int function. 
 *   Inquiry is interrupt P04 occured.
 *   param    :     void
 *   return   :     char P_INT_OCCURED       interrupt occured
 *                       P_INT_NOT_OCCURED   interrupt nnot occured
 *   history  :     2008/03/26	start
 ***********************************************************************/
 char isP04Int(void) {
	/* interrupt flag*/
	unsigned char intFlag;

	//port interrupt flag (D[0:7] /0x5207
	intFlag = P0_IFLG;

	if((intFlag & P_BIT_X4) == P_BIT_X4) {
		return P_INT_OCCURED;				//interrupt occured
	} else {
		return P_INT_NOT_OCCURED;
	}
 }


 /************************************************************************
 * 	 isP05Int function. 
 *   Inquiry is interrupt P05 occured.
 *   param    :     void
 *   return   :     char P_INT_OCCURED       interrupt occured
 *                       P_INT_NOT_OCCURED   interrupt nnot occured
 *   history  :     2008/03/26	start
 ***********************************************************************/
 char isP05Int(void) {
	/* interrupt flag*/
	unsigned char intFlag;
	
	//port interrupt flag (D[0:7] /0x5207
	intFlag = P0_IFLG;

	if((intFlag & P_BIT_X5) == P_BIT_X5) 
	return P_INT_OCCURED;				//interrupt occured

	return P_INT_NOT_OCCURED;
 }

 /************************************************************************
 * 	 isP06Int function. 
 *   Inquiry is interrupt P06 occured.
 *   param    :     void
 *   return   :     char P_INT_OCCURED       interrupt occured
 *                       P_INT_NOT_OCCURED   interrupt nnot occured
 *   history  :     2008/03/26	start
 ***********************************************************************/
 char isP06Int(void) {
	/* interrupt flag*/
	unsigned char intFlag;
	
	//port interrupt flag (D[0:7] /0x5207
	intFlag = P0_IFLG;

	if((intFlag & P_BIT_X6) == P_BIT_X6) {
		return P_INT_OCCURED;				//interrupt occured
	} else {
		return P_INT_NOT_OCCURED;
	}
 }

 /************************************************************************
 * 	 isP07Int function. 
 *   Inquiry is interrupt P07 occured.
 *   param    :     void
 *   return   :     char P_INT_OCCURED       interrupt occured
 *                       P_INT_NOT_OCCURED   interrupt nnot occured
 *   history  :     2008/03/26	start
 ***********************************************************************/
 char isP07Int(void) {
	/* interrupt flag*/
	unsigned char intFlag;
	
	//port interrupt flag (D[0:7] /0x5207
	intFlag = P0_IFLG;

	if((intFlag & P_BIT_X7) == P_BIT_X7) {
		return P_INT_OCCURED;				//interrupt occured
	} else {
		return P_INT_NOT_OCCURED;
	}
 }

 /************************************************************************
 * 	 isP10Int function. 
 *   Inquiry is interrupt P10 occured.
 *   param    :     void
 *   return   :     char P_INT_OCCURED       interrupt occured
                         P_INT_NOT_OCCURED   interrupt nnot occured
 *   history  :     2008/03/26	start
 ***********************************************************************/
 char isP10Int(void) {
	/* interrupt flag*/
	unsigned char intFlag;
	
	//port interrupt flag (D[0:7] /0x5217
	intFlag = P1_IFLG;

	if((intFlag & P_BIT_X0) == P_BIT_X0) {
		return P_INT_OCCURED;				//interrupt occured
	} else {
		return P_INT_NOT_OCCURED;
	}
 }

 /************************************************************************
 * 	 isP11Int function. 
 *   Inquiry is interrupt P11 occured.
 *   param    :     void
 *   return   :     char P_INT_OCCURED       interrupt occured
 *                       P_INT_NOT_OCCURED   interrupt nnot occured
 *   history  :     2008/03/26	start
 ***********************************************************************/
 char isP11Int(void) {
	/* interrupt flag*/
	unsigned char intFlag;
	
	//port interrupt flag (D[0:7] /0x5217
	intFlag = P1_IFLG;

	if((intFlag & P_BIT_X1) == P_BIT_X1) {
		return P_INT_OCCURED;				//interrupt occured
	} else {
		return P_INT_NOT_OCCURED;
	}
 }

 /************************************************************************
 * 	 isP12Int function. 
 *   Inquiry is interrupt P12 occured.
 *   param    :     void
 *   return   :     char P_INT_OCCURED       interrupt occured
 *                       P_INT_NOT_OCCURED   interrupt nnot occured
 *   history  :     2008/03/26	start
 ***********************************************************************/
 char isP12Int(void) {
	/* interrupt flag*/
	unsigned char intFlag;
	
	//port interrupt flag (D[0:7] /0x5217
	intFlag = P1_IFLG;

	if((intFlag & P_BIT_X2) == P_BIT_X2) {
		return P_INT_OCCURED;				//interrupt occured
	} else {
		return P_INT_NOT_OCCURED;
	}
 }

 /************************************************************************
 * 	 isP13Int function.
 *   Inquiry is interrupt P13 occured.
 *   param    :     void
 *   return   :     char P_INT_OCCURED       interrupt occured
 *                       P_INT_NOT_OCCURED   interrupt nnot occured
 *   history  :     2008/03/26	start
 ***********************************************************************/
 char isP13Int(void) {
	/* interrupt flag*/
	unsigned char intFlag;
	
	//port interrupt flag (D[0:7] /0x5217
	intFlag = P1_IFLG;

	if((intFlag & P_BIT_X3) == P_BIT_X3) {
		return P_INT_OCCURED;				//interrupt occured
	} else {
		return P_INT_NOT_OCCURED;
	}
 }

 /************************************************************************
 * 	 isP14Int function. 
 *   Inquiry is interrupt P14 occured.
 *   param    :     void
 *   return   :     char P_INT_OCCURED       interrupt occured
 *                       P_INT_NOT_OCCURED   interrupt nnot occured
 *   history  :     2008/03/26	start
 ***********************************************************************/
 char isP14Int(void) {
	/* interrupt flag*/
	unsigned char intFlag;
	
	//port interrupt flag (D[0:7] /0x5217
	intFlag = P1_IFLG;

	if((intFlag & P_BIT_X4) == P_BIT_X4) {
		return P_INT_OCCURED;				//interrupt occured
	} else {
		return P_INT_NOT_OCCURED;
	}
 }

 /************************************************************************
 * 	 isP15Int function. 
 *   Inquiry is interrupt P15 occured.
 *   param    :     void
 *   return   :     char P_INT_OCCURED       interrupt occured
 *                       P_INT_NOT_OCCURED   interrupt nnot occured
 *   history  :     2008/03/26	start
 ***********************************************************************/
 char isP15Int(void) {
	/* interrupt flag*/
	unsigned char intFlag;
	
	//port interrupt flag (D[0:7] /0x5217
	intFlag = P1_IFLG;

	if((intFlag & P_BIT_X5) == P_BIT_X5) {
		return P_INT_OCCURED;				//interrupt occured
	} else {
		return P_INT_NOT_OCCURED;
	}
 }

 /************************************************************************
 * 	 isP16Int function. 
 *   Inquiry is interrupt P16 occured.
 *   param    :     void
 *   return   :     char P_INT_OCCURED       interrupt occured
 *                       P_INT_NOT_OCCURED   interrupt nnot occured
 *   history  :     2008/03/26	start
 ***********************************************************************/
 char isP16Int(void) {
	/* interrupt flag*/
	unsigned char intFlag;
	
	//port interrupt flag (D[0:7] /0x5207
	intFlag = P1_IFLG;

	if((intFlag & P_BIT_X6) == P_BIT_X6) {
		return P_INT_OCCURED;				//interrupt occured
	} else {
		return P_INT_NOT_OCCURED;
	}
 }

 /************************************************************************
 * 	 isP17Int function. 
 *   Inquiry is interrupt P17 occured.
 *   param    :     void
 *   return   :     char P_INT_OCCURED       interrupt occured
 *                       P_INT_NOT_OCCURED   interrupt nnot occured
 *   history  :     2008/03/26	start
 ***********************************************************************/
 char isP17Int(void) {
	/* interrupt flag*/
	unsigned char intFlag;
	
	//port interrupt flag (D[0:7] /0x5207
	intFlag = P1_IFLG;

	if((intFlag & P_BIT_X7) == P_BIT_X7) {
		return P_INT_OCCURED;				//interrupt occured
	} else {
		return P_INT_NOT_OCCURED;
	}
 }

