 /***********************************************************************
 *                                                                      *
 * t16.c                                                                *
 * This is t16 driver program file for SVT17702.                        *
 * History :  2008/03/28  Start.                                        *
 *                                                                      *
 ************************************************************************/

#include "s1c17702.h"
#include "t16.h"

/************************************************************************
 * 	 initT16Ch0 function.
 *   T16 CH0 timer start.
 *   param    :     InitParamT16 initParam:T16 info
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void initT16Ch0(InitParamT16* initParam) {
	//Stop timer
	stopT16Ch0();
	
	// Input clock and pulse width measurement mode select (D[8:9]/0x4226)
	T16_CTL0_CKSL = initParam->clkMode;
	
	// Count mode select (D[4]/0x4226)
	T16_CTL0_TRMD = initParam->cntMode;
	
	if(initParam->clkMode != T16_CLK_MODE_OUT) {
		//Timer input clock select (D[0:3]/0x4220)
		T16_CLK0_DF = initParam->cntClock;
	}
	
	if(initParam->clkMode != T16_CLK_MODE_IN) {
		// External clock active level select (D[10]/0x4226)
		T16_CTL0_CKACTV = initParam->exActiveLv;
	}

	//Reload value
	// 16-bit Timer Ch.0 Reload Data Register (D[0:15]/0x4222)
	T16_TR0 = initParam->count;

	resetT16Ch0Count();
 }


/************************************************************************
 * 	 initT16Ch1 function.
 *   T16 CH1 timer start.
 *   param    :     InitParamT16 initParam:T16 info
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void initT16Ch1(InitParamT16* initParam) {
	//Stop timer
	stopT16Ch1();
	
	// Input clock and pulse width measurement mode select (D[8:9]/0x4246)
	T16_CTL1_CKSL = initParam->clkMode;
	
	// Count mode select (D[4]/0x4246)
	T16_CTL1_TRMD = initParam->cntMode;
	
	if(initParam->clkMode != T16_CLK_MODE_OUT) {
		//Timer input clock select (D[0:7]/0x4240)
		T16_CLK1_DF = initParam->cntClock;
	}
	
	if(initParam->clkMode != T16_CLK_MODE_IN) {
		// External clock active level select (D[10]/0x4246)
		T16_CTL1_CKACTV = initParam->exActiveLv;
	}

	//Reload value
	// 16-bit Timer Ch.1 Reload Data Register (D[0:15]/0x4242)
	T16_TR1 = initParam->count;

	resetT16Ch1Count();
 }

/************************************************************************
 * 	 initT16Ch2 function.
 *   T16 CH2 timer start.
 *   param    :     InitParamT16 initParam:T16 info
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void initT16Ch2(InitParamT16* initParam) {
	//Stop timer
	stopT16Ch2();

	// Input clock and pulse width measurement mode select (D[8:9]/0x4266)
	T16_CTL2_CKSL = initParam->clkMode;
	
	// Count mode select (D[4]/0x4266)
	T16_CTL2_TRMD = initParam->cntMode;
	
	if(initParam->clkMode != T16_CLK_MODE_OUT) {
		//Timer input clock select (D[0:7]/0x4260)
		T16_CLK2_DF = initParam->cntClock;
	}
	
	if(initParam->clkMode != T16_CLK_MODE_IN) {
		// External clock active level select (D[10]/0x4266)
		T16_CTL2_CKACTV = initParam->exActiveLv;
	}

	//Reload value
	// 16-bit Timer Ch.1 Reload Data Register (D[0:15]/0x4262)
	T16_TR2 = initParam->count;

	resetT16Ch2Count();
 }

/************************************************************************
 * 	 startT16Ch0 function.
 *   T16 CH0 timer start.
 *   param    :     void
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void startT16Ch0(void) {
 	// Timer stop (D[0]/0x4226)
 	T16_CTL0_PRUN = 0x01;
 }

/************************************************************************
 * 	 startT16Ch1 function.
 *   T16 CH1 timer start.
 *   param    :     void
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void startT16Ch1(void) {
 	// Timer stop (D[0]/0x4246)
 	T16_CTL1_PRUN = 0x01;
 }
 
/************************************************************************
 * 	 startT16Ch2 function.
 *   T16 CH2 timer start.
 *   param    :     void
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void startT16Ch2(void) {
 	// Timer stop (D[0]/0x4266)
 	T16_CTL2_PRUN = 0x01;
 }
 

/************************************************************************
 * 	 stopT16Ch0 function.
 *   T16 CH0 timer stop.
 *   param    :     void
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void stopT16Ch0(void) {
 	// Timer stop (D[0]/0x4226)
 	T16_CTL0_PRUN = 0x00;
 }

/************************************************************************
 * 	 stopT16Ch1 function.
 *   T16 CH1 timer stop.
 *   param    :     void
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void stopT16Ch1(void) {
 	// Timer stop (D[0]/0x4246)
 	T16_CTL1_PRUN = 0x00;
 }
 
/************************************************************************
 * 	 stopT16Ch2 function.
 *   T16 CH2 timer stop.
 *   param    :     void
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void stopT16Ch2(void) {
 	// Timer stop (D[0]/0x4266)
 	T16_CTL2_PRUN = 0x00;
 }
 
 /************************************************************************
 * 	 resetT16Ch0Count function.
 *   T16 CH0 timer reset.
 *   param    :     void
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void resetT16Ch0Count(void) {
 	// Timer reset (D[1]/0x4226)
 	T16_CTL0_PRESER = 0x01;
 }

/************************************************************************
 * 	 resetT16Ch1Count function.
 *   T16 CH1 timer reset.
 *   param    :     void
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void resetT16Ch1Count(void) {
 	// Timer reset (D[1]/0x4246)
 	T16_CTL1_PRESER = 0x01;
 }
 
/************************************************************************
 * 	 resetT16Ch2Count function.
 *   T16 CH2 timer reset.
 *   param    :     void
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void resetT16Ch2Count(void) {
 	// Timer reset (D[1]/0x4266)
 	T16_CTL2_PRESER = 0x01;
 }

 /************************************************************************
 * 	 getT16Ch0Count function.
 *   Get T16 CH0 timer counter value.
 *   param    :     void
 *   return   :     unsigned short : count data
 *   history  :     2008/03/28   start
 ***********************************************************************/
 unsigned short getT16Ch0Count(void) {
	/*count data*/
	unsigned short countVal1;
	
 	// 16-bit Timer Ch.0 Counter Data Register (D[0:7]/0x4224)
	countVal1 = T16_TC0;
	return countVal1;
 }

 /************************************************************************
 * 	 getT16Ch1Count function.
 *   Get T16 CH1 timer counter value.
 *   param    :     void
 *   return   :     unsigned short : count data
 *   history  :     2008/03/28   start
 ***********************************************************************/
 unsigned short getT16Ch1Count(void) {
	/*count data*/
	unsigned short countVal1;
 	// 16-bit Timer Ch.0 Counter Data Register (D[0:7]/0x4244)
	countVal1 = T16_TC1;

	return countVal1;
 }

 /************************************************************************
 * 	 getT16Ch2Count function.
 *   Get T16 CH2 timer counter value.
 *   param    :     void
 *   return   :     unsigned short : count data
 *   history  :     2008/03/28   start
 ***********************************************************************/
 unsigned short getT16Ch2Count(void) {
	/*count data*/
	unsigned short countVal1;
	
 	// 16-bit Timer Ch.2 Counter Data Register (D[0:7]/0x4264)
	countVal1 = T16_TC2;

	return countVal1;
 }

 /************************************************************************
 * 	 initT16Ch0Int function.
 *   T16 CH0 timer interrput initialize.
 *   param    :     char intLevel:interrupt level
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void initT16Ch0Int(unsigned char intLevel) {
	//interrput disable
	stopT16Ch0Int();
	// T16 Ch.0 interrupt level  (D[8:10]/0x430e)
	ITC_LV4_ILV9 = intLevel;
 }

 /************************************************************************
 * 	 initT16Ch1Int function.
 *   T16 CH1 timer interrput initialize.
 *   param    :     char intLevel:interrupt level
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void initT16Ch1Int(unsigned char intLevel) {
	//interrput disable
	stopT16Ch1Int();
	// T16 Ch.1 interrupt level  (D[0:2]/0x4310)
	ITC_LV5_ILV10 = intLevel;
 }

 /************************************************************************
 * 	 initT16Ch2Int function.
 *   T16 CH2 timer interrput initialize.
 *   param    :     char intLevel:interrupt level
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void initT16Ch2Int(unsigned char intLevel) {
	//interrput disable
	stopT16Ch2Int();
	// T16 Ch.2 interrupt level  (D[8:10]/0x4310)
	ITC_LV5_ILV11 = intLevel;
 }


 /************************************************************************
 * 	 startT16Ch0Int function.
 *   T16 CH0 timer interrupt enable.
 *   param    :     void
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void startT16Ch0Int(void) {
	// 16-bit timer Ch.0 interrupt flag clear (D[0]/0x4228)
	resetT16Ch0IF();
	
	// 16-bit timer Ch.0 interrupt enable (D[8]/0x4228)
	T16_INT0_T16IE = 0x1;
 }
 

 /************************************************************************
 * 	 startT16Ch1Int function.
 *   T16 CH1 timer interrupt enable.
 *   param    :     void
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void startT16Ch1Int(void) {
	// 16-bit timer Ch.1 interrupt flag clear (D[0]/0x4248)
	resetT16Ch1IF();
	
	// 16-bit timer Ch.1 interrupt enable (D[8]/0x4248)
	T16_INT1_T16IE = 0x1;
 }

 /************************************************************************
 * 	 startT16Ch2Int function.
 *   T16 CH2 timer interrupt enable.
 *   param    :     void
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void startT16Ch2Int(void) {
	// 16-bit timer Ch.2 interrupt flag clear (D[0]/0x4268)
	resetT16Ch2IF();
	
	// 16-bit timer Ch.2 interrupt enable (D[8]/0x4268)
	T16_INT2_T16IE = 0x1;
 }
 
 /************************************************************************
 * 	 stopT16Ch0Int function.
 *   T16 CH0 timer interrupt disable.
 *   param    :     void
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void stopT16Ch0Int(void) {
	// 16-bit timer Ch.0 interrupt enable (D[8]/0x4228)
	T16_INT0_T16IE = 0x0;
 }

 /************************************************************************
 * 	 stopT16Ch1Int function.
 *   T16 CH1 timer interrupt disable.
 *   param    :     void
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void stopT16Ch1Int(void) {
	// 16-bit timer Ch.1 interrupt enable (D[8]/0x4248)
	T16_INT1_T16IE = 0x0;
 }

 /************************************************************************
 * 	 stopT16Ch2Int function.
 *   T16 CH2 timer interrupt disable.
 *   param    :     void
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void stopT16Ch2Int(void) {
	// 16-bit timer Ch.2 interrupt enable (D[8]/0x4268)
	T16_INT2_T16IE = 0x0;
 }

 /************************************************************************
 * 	 resetT16Ch0IF function.
 *   T16 CH0 timer interrupt flag clear.
 *   param    :     void
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void resetT16Ch0IF(void) {
	// 16-bit timer Ch.0 interrupt flag clear (D[0]/0x4228)
	T16_INT0_T16IF = 0x1;
 }
 
 /************************************************************************
 * 	 resetT16Ch1IF function.
 *   T16 CH1 timer interrupt flag clear.
 *   param    :     void
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void resetT16Ch1IF(void) {
	// 16-bit timer Ch.1 interrupt flag clear (D[0]/0x4248)
	T16_INT1_T16IF = 0x1;
 }
 
  /************************************************************************
 * 	 resetT16Ch2IF function.
 *   T16 CH2 timer interrupt flag clear.
 *   param    :     void
 *   return   :     none
 *   history  :     2008/03/28   start
 ***********************************************************************/
 void resetT16Ch2IF(void) {
	// 16-bit timer Ch.2 interrupt flag clear (D[0]/0x4268)
	T16_INT2_T16IF = 0x1;
 }
