 /***********************************************************************
 *                                                                      *
 * main.c                                                               *
 * Sound test by TK      		                       	*
 * History : 2010/04/13 	start                                   *
 ***********************************************************************/
#include <string.h>
#include "osc.h"
#include "t16.h"
#include "lcd.h"
#include "port.h"
#include "init.h"
#include "lcdManager.h"

/*proto type*/
void t16ch0Int(void)__attribute__ ((interrupt_handler));
void t16ch1Int(void)__attribute__ ((interrupt_handler));
void p0xInt(void)__attribute__ ((interrupt_handler));
void timer1init(int); //**TK**
void display2lcd(void)__attribute__ ((interrupt_handler)); //**TK**
void Wait(void);
void hardware_init(void);
int main(void);
int random(void); //**TK**
void setNum(unsigned int,unsigned int); //**TK**

void setSound(int); //**TK**

/* Global variable define */
 volatile unsigned char t16ch0Flg;
 volatile unsigned char sw2Flg;
 volatile unsigned char sw3Flg;
 volatile unsigned int random_seed;			// **TK** valuable for semi-random function

 /* work for non-grayscale text screen */
 volatile unsigned char buf[12*4]; 			// **TK** virtual screen buffer
 volatile unsigned char line_buf[13];		// **TK** line buffer to call displayStr()

 /* work for grayscale screen */
 volatile unsigned char temp_screen[80*5*3]; /* 3 planes for 4 gray scales */
 volatile int lcd_counter ;


/************************************************************************
 *   main function.
 *   param    :     void
 *   return   :     none
 *   history  :     2009/01/14	start
 ***********************************************************************/
int main(void) {

	controlPsc(PSC_PRUN_RUN);        			//prescaler run
	setClockGear(CLG_CCLKGR_1);      			//set clock gear *defalt=0x0

	//IOSC->OSC3
	SET_OSC3_WAIT_CYCLE(OSC3_WAIT_CYCLE_256);
	changeSysClkIoscTo3();
	hardware_init();

	//clear LCD
	clearAllLcdLine();
	Wait();

	//Init display
	clearAllLcdLine();
	displayStr(0,"Sound");
	displayStr(1,"Test V1.0");
	displayStr(2,"by T.K");
	displayStr(3,"**push sw2**");
	reverseStr(0);

	while (1){
		//SW2 wait
		sw2Flg = 0;
		while(sw2Flg == 0){}; sw2Flg = 0;

		//Sound testing
		clearAllLcdLine();
		displayStr(1,"Playing now");
		setSound(220); Wait();Wait();
		setSound(247); Wait();Wait();
		setSound(277); Wait();Wait();
		setSound(294); Wait();Wait();
		setSound(330); Wait();Wait();
		setSound(370); Wait();Wait();
		setSound(415); Wait();Wait();
		setSound(440); Wait();Wait();
		setSound(0);
		displayStr(1,"Done push sw2.");
	}
	return 1;
}



 /************************************************************************
 *   t16ch1Int function.
 * 	 t16Ch1 interrupt routine.
 *   param    :     void
 *   return   :     none
 *   history  :     2009/01/14   start
 ***********************************************************************/
void t16ch1Int(void) {

	resetT16Ch1IF();
	P2_OUT ^= 0x80;			//LED ON/OFF

}

/************************************************************************
 *   t16ch0Int function.
 * 	 t16Ch0 interrupt routine.
 *   param    :     void
 *   return   :     none
 *   history  :     2009/01/14   start
 ***********************************************************************/
void t16ch0Int(void) {
	resetT16Ch0IF();
	t16ch0Flg = 1;
 }
 /************************************************************************
 *	 p0xInt function.
 *   P0X interrupt routine.
 *   param    :     void
 *   return   :     int
 *   history  :     2009/01/14	start
 ***********************************************************************/
 void p0xInt(void) {
	/* interrupt flag*/
	char intFlag = 0;
	//Check Interrupt status
	if(isP06Int() == P_INT_OCCURED) {
		//P06 intterupt occured
		intFlag |= P_BIT_X6;
		sw2Flg = 1;
	}
	if(isP07Int() == P_INT_OCCURED) {
		//P07 intterupt occured
		intFlag |= P_BIT_X7;
		sw3Flg = 1;
	}
	//Interrupt Flag clear
	resetP0IF((unsigned char) intFlag);
 }

 /************************************************************************
  *   Transfer virtual screen data to LCD display at LCD interrupt
  *   param    :     void
  *   return   :     none
  *   history  :     2010/03/17	start
  ***********************************************************************/
 void display2lcd(void){		//**TK**
	 switch (lcd_counter) {
		case 0:
			 displayTempScreen((char *)temp_screen + 400 *2 );			//**TK**
			 break;
		case 1:
			 displayTempScreen((char *)temp_screen + 400);			//**TK**
			 break;
		case 2:
			 displayTempScreen((char *)temp_screen);			//**TK**
			 break;
	 }

	 lcd_counter ++;
	 if (lcd_counter > 2) {
		 lcd_counter = 0;
	 }
 	resetLcdIF();				//**TK**
 }

 /************************************************************************
  *   Generating semi-random number
  *   param    :     void
  *   return   :     0-255 random number
  *   history  :     2010/03/17	start
  ***********************************************************************/
 int random(void){								//**TK**
 	random_seed = (random_seed * 113 + 7);		//**TK**
 	return (random_seed % 0x100);				//**TK**
 }

 /************************************************************************
   *   Display
   *   param    :     num : unsigned int value to be displayed
   *   				  loc : column location in line_buffer
   *   return   :     none
   *   history  :     2010/03/17	start
   ***********************************************************************/
  void setNum(unsigned int loc,unsigned int num){	//**TK**
	unsigned int i,cmp;							//**TK**
  	i = 0 ;										//**TK**
  	cmp = 10000;
  	for (i = 0; i < 5; i++) {
  		line_buf[loc+i] = num / cmp + 0x30;
  		num = num % cmp;
  		cmp /= 10;
  	}
  	line_buf[loc+i] ='\0';
  }

 /************************************************************************
 *   Wait function.
 *   wait.
 *   param    :     void
 *   return   :     none
 *   history  :     2009/01/14	start
 ***********************************************************************/
void Wait(void) {

	t16ch0Flg = 0;
	//start T16CH0 timer
	startT16Ch0();

	//T16CH0 timer interrupt enable
	startT16Ch0Int();

	while(t16ch0Flg != 1){
	    asm("halt");
		asm("nop");
    }
}
/************************************************************************
 *   hardware init function.
 *   software wait.
 *   param    :     void
 *   return   :     none
 *   history  :     2009/01/14	start
 ***********************************************************************/
void hardware_init(void) {

	InitParamT16 initParam;

	/*---------------------------------------------*/
	//P06,P07 = INPUT
	setPortInput(0xC0, 0x00, 0x00, 0x00);
	//P27 = OUTPUT
	setPortOutput(0x00, 0x00, 0x80, 0x00);
	contorlP0IputOn(0xC0);
	initP0Int(0x03);
 	setP0IntEdgeDown(0xC0);
	setP0Chat4to7(P0_CAHT_TIME_PCLK_8192);
	startP0Int(0xC0);

	/*---------------------------------------------*/
	// TOUT4 output enable
	P0_PMUX_P04MUX 	= 1;			// TOUT4 select
	P0_IO_P0IO 		|= 0x10;		// P4 output enable
	P0_IEN_P0IEN 	&= 0xEF;		// P4 input disable

	// T16E ch1 setting
	T16E_CLK1_T16EDF = 0x09;		// CLK = PCLK/2048 = about 16KHz
	T16E_CTL1_INITOL = 0;			// Initial level = LOW
	T16E_CTL1_SELFM = 1;			// fine mode select
	T16E_CTL1_CBUFEN = 1;			// Comparison enable
	T16E_CTL1_INVOUT = 0;			// No invert output
	T16E_CTL1_CLKSEL = 0;			// internal clock select
	T16E_CTL1_OUTEN = 1;			// Clock output enabled
	T16E_CTL1_T16ERST = 1;			// counter reset
	T16E_CTL1_T16ERUN = 0;			// Timer stop

	T16E_INT1_CBIE = 0;				// No interrupt for counter B
	T16E_INT1_CAIE = 0;				// No interrupt for counter A

	/*---------------------------------------------*/
	//T16 CH0 setting(wait 0.25s setting)
    initParam.clkMode = T16_CLK_MODE_IN;		//internal
	initParam.cntMode = T16_CNT_MODE_ONESHOT;	//oneshot
	initParam.cntClock = T16_IN_CLOCK_8192;     //1/8192
	initParam.exActiveLv = T16_EX_ACTIVE_LV_UP;	//Polar 1:Rise
	//initParam.count = 0x003cf * 2;	                //reload data 975
	initParam.count = 0x0080;	                //**TK**

    initT16Ch0(&initParam);
	initT16Ch0Int(0x03);

	/*---------------------------------------------*/
	//T16 CH1 setting(moved by TK)
	timer1init(3);

	/*---------------------------------------------*/
	// initializes LCD
	initLcdPower(LCD_PWR_BOOSTER_OFF, LCD_HEAVY_PROTECT_OFF);
	startLcdClk(LCD_CLK_SELECT_HSCLK, LCD_CLK_DIV_32);
	initLcd(LCD_DUTY_32, LCD_CONTRAST_LV_10);
	reverseLcdCom();
	reverseLcdSeg();
	initLcdInt(0x03);		//**TK**
	lcdOn();
}

void timer1init(int timer_value) {

	InitParamT16 initParam;

	stopT16Ch1();
	stopT16Ch1Int();
    initParam.clkMode = T16_CLK_MODE_IN;		//internal
	initParam.cntMode = T16_CNT_MODE_REPEAT;	//repeat
	initParam.cntClock = T16_IN_CLOCK_8192;     //1/8192
	initParam.exActiveLv = T16_EX_ACTIVE_LV_UP;	//Polar 1:Rise
	//initParam.count = 0x01e7 ;	                //reload data 487
	initParam.count = 0x01e7 /3 * timer_value ;	                //**TK**
    initT16Ch1(&initParam);
	initT16Ch1Int(0x03);
	startT16Ch1();
	startT16Ch1Int();
}

void setSound(int frequency) {
	int work;
	if ((frequency>0)&&(frequency<=8000)){
		work = 16000/frequency;
		T16E_CB1_T16ECB = work;
		T16E_CA1_T16ECA = work/2;
		T16E_CTL1_T16ERST = 1;			// counter reset
		T16E_CTL1_T16ERUN = 1;			// Timer start
	}
	if (frequency == 0){
		T16E_CTL1_T16ERST = 1;			// counter reset
		T16E_CTL1_T16ERUN = 0;			// Timer stop
	}
}
